summaryrefslogtreecommitdiffstats
path: root/win
diff options
context:
space:
mode:
authorchengyemao <chengyemao>2005-10-05 00:43:45 (GMT)
committerchengyemao <chengyemao>2005-10-05 00:43:45 (GMT)
commitdc15e989855b9081fcd9d2951c0fbed6103928c7 (patch)
tree988a342df9086a882f1bf30da8a844f602d7be63 /win
parent440cc7e1303fe245a83684186494fdf558edc50a (diff)
downloadtk-dc15e989855b9081fcd9d2951c0fbed6103928c7.zip
tk-dc15e989855b9081fcd9d2951c0fbed6103928c7.tar.gz
tk-dc15e989855b9081fcd9d2951c0fbed6103928c7.tar.bz2
Fixed bug #1311734
Diffstat (limited to 'win')
-rw-r--r--win/tkWinWm.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/win/tkWinWm.c b/win/tkWinWm.c
index 7de2134..f52942e 100644
--- a/win/tkWinWm.c
+++ b/win/tkWinWm.c
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkWinWm.c,v 1.101 2005/09/11 01:37:15 chengyemao Exp $
+ * RCS: @(#) $Id: tkWinWm.c,v 1.102 2005/10/05 00:43:45 chengyemao Exp $
*/
#include "tkWinInt.h"
@@ -7226,11 +7226,11 @@ InvalidateSubTreeDepth(winPtr)
for (childPtr = winPtr->childList; childPtr != NULL;
childPtr = childPtr->nextPtr) {
/*
* We can stop the descent when we hit a toplevel window, as it
* should get its own message.
*/
- if (!Tk_TopWinHierarchy(childPtr)) {
+ if (childPtr->flags & TK_EMBEDDED || !Tk_TopWinHierarchy(childPtr)) {
InvalidateSubTreeDepth(childPtr);
}
}
@@ -7226,11 +7226,11 @@ InvalidateSubTreeDepth(winPtr)
childPtr = childPtr->nextPtr) {
/*
- * We can stop the descent when we hit a toplevel window, as it
- * should get its own message.
+ * We can stop the descent when we hit a non-embedded toplevel window,
+ * as it should get its own message.
*/